##  Quick Search Mode
![Quick Search Mode](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274194f57a441014927efbd7ee088225_LowRes.png)
Quick Search Mode
The Quick Search Mode setting determines the default view for quick search results in your workspace. You can choose to see the results in a single list or view them grouped by Fact Sheet type. While you can easily switch modes in the search tab, the default mode is based on what you have chosen in the Quick Search Mode setting.
![Switching Quick Search Mode in the Search Bar](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755fad97a441014a506b3a842ff004d_LowRes.gif)
Switching Quick Search Mode in the Search Bar
